local addon, db = ...

local frame = CreateFrame"Frame"
frame:SetScript("OnEvent", function (self, event, ...)
	local handlers = self[event]
	if handlers then
		for handler in next, handlers do
			if not handler(self, event, ...) then
				handlers[handler] = nil
			end
		end
		if not next(handlers) then
			self:UnregisterEvent(event)
			self[event] = nil
		end
	end
end)

function db.Register(handler, ...)
	for i = 1, select("#", ...) do
		local event = select(i, ...)
		local handlers = frame[event]
		if not handlers then
			handlers = {}
			frame[event] = handlers
			frame:RegisterEvent(event)
		end
		handlers[handler] = true
	end
end


db.Register(function ()
	db.SV = VendorAutomateDB or {
		GLYPH_ONCE_IS_ENOUGH = nil
	}
	VendorAutomateDB = db.SV
	db.init_junk()
	db.init_reagents()
	db.init_repair()
	db.init_junk = nil
	db.init_reagents = nil
	db.init_repair = nil
end, "VARIABLES_LOADED")
